@@ -2,15 +2,18 @@
 from __future__ import absolute_import, unicode_literals, division
 from ._version import __version__, __version_info__  # noqa
 from .decorators import rule, deferred_rule
-from .predicate import Predicate as P
-from .utils import register, has, filter
+from .utils import has
+from .utils import filter_ as filter
+from ._registry import registry
+
+
+register = registry.register
 
 
 __all__ = [
     'rule',
     'deferred_rule',
-    'P',
-    'register',
     'has',
-    'filter'
+    'filter',
+    'register'
 ]
